@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Alien;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: Dist::Zilla::PluginBundle::Basic for Alien
-$Dist::Zilla::PluginBundle::Alien::VERSION = '0.023';
+$Dist::Zilla::PluginBundle::Alien::VERSION = '0.024';
 use Moose;
 use Dist::Zilla;
 use Dist::Zilla::Plugin::Alien;
@@ -42,7 +42,7 @@ Dist::Zilla::PluginBundle::Alien - Dist::Zilla::PluginBundle::Basic for Alien
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
@@ -55,9 +55,23 @@ In your B<dist.ini>:
 
 =head1 DESCRIPTION
 
+B<NOTE>: This module uses the older, and still supported, but not actively
+developed L<Alien::Base::ModuleBuild> interface for installing aliens. You
+should use L<Dist::Zilla::Plugin::AlienBuild> for new L<Alien>s, and consider
+migration for older code as well.
+
 This plugin bundle allows to use L<Dist::Zilla::Plugin::Alien> together
 with L<Dist::Zilla::PluginBundle::Basic>.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/PerlAlien/Dist-Zilla-Plugin-Alien/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Torsten Raudssus <torsten@raudss.us>
